@@ -127,6 +127,11 @@ set( 'SQL_EMPLOYEE_SELECT_TEAM', q/
      SELECT nick FROM employees WHERE supervisor = ? ORDER BY nick
      / );
 
+#
+set( 'SQL_EMPLOYEE_HAS_REPORTS', q/
+     SELECT has_reports(?)
+     / );
+
 #
 set( 'SQL_EMPLOYEE_PRIV_CHANGE_DURING_RANGE', q/
      SELECT priv_change_during_range( ?, ? )
